import type { NextPage } from "next";
import dynamic from "next/dynamic";
import Link from "next/link";
import { ExpressionSetInfo } from "../../components/ExpressionSetInfo/ExpressionSetInfo";
import { Page } from "../../components/Page";
import { useExpressionSet } from "../../hooks/useExpressionSet";
import { useExpressionSetQueryId } from "../../hooks/useExpressionSetQueryId";
import { useExpressionsInSet } from "../../hooks/useExpressionsInSet";
import { PageWithError } from "../../views/PageWithError/PageWithError";

function pageTitle(name?: string) {
  return `Flash Card App - ${name || "Sets"}`;
}

const ExpressionSetDetailsPage: NextPage = () => {
  const expression_set_id = useExpressionSetQueryId();
  const expression_set = useExpressionSet(expression_set_id);
  const expressions = useExpressionsInSet(expression_set_id);

  // Fallback for expression set not found
  if (!expression_set) {
    return (
      <PageWithError title={pageTitle()} message="Expression set not found" />
    );
  }

  // Fallback for expression set empty
  if (expressions.length === 0)
    return (
      <Page title={pageTitle(expression_set.name)}>
        <div className="page-with-padding scroll">
          <ExpressionSetInfo
            id={expression_set.id!}
            name={expression_set.name}
            description={expression_set.description}
            expression_count={expressions.length}
          />
          <p className="text-details">No expressions left in this set.</p>
        </div>
      </Page>
    );

  return (
    <Page title={pageTitle(expression_set.name)}>
      <div className="page-with-bottom-navigation">
        <section className="padding-small scroll">
          <ExpressionSetInfo
            id={expression_set.id!}
            name={expression_set.name}
            description={expression_set.description}
            expression_count={expressions.length}
          />
        </section>
        <section className="navigation-bottom">
          <Link
            href={{
              pathname: "/expression-sets/practice",
              query: { "set-id": expression_set.id },
            }}
            passHref
          >
            <a className="navigation-item bottom text-navigation grow">
              <span>Practice this set</span>
            </a>
          </Link>
        </section>
      </div>
    </Page>
  );
};

export default dynamic(() => Promise.resolve(ExpressionSetDetailsPage), {
  ssr: false,
});
