import type { NextPage } from "next";
import dynamic from "next/dynamic";
import Link from "next/link";
import { ExpressionSetCard } from "../../components/ExpressionSetCard";
import { Page } from "../../components/Page";
import { useExpressionSets } from "../../hooks/useExpressionSets";
import { useExpressionsInSet } from "../../hooks/useExpressionsInSet";
import { IndexedExpressionSet } from "../../model";
import { PageWithError } from "../../views/PageWithError";

const PageTitle = "Flash Card App - Sets";

const ExpressionSetListPage: NextPage = () => {
  const expression_sets = useExpressionSets();

  if (!expression_sets?.length) {
    return (
      <PageWithError title={PageTitle} message="No expression sets found" />
    );
  }

  return (
    <Page title={PageTitle}>
      <div className="page-with-padding content-list scroll">
        {expression_sets.map(({ id, name, description }) => (
          <ExpressionSetLink
            key={id}
            id={id}
            name={name}
            description={description}
          />
        ))}
      </div>
    </Page>
  );
};

function ExpressionSetLink({ id, description, name }: IndexedExpressionSet) {
  const expressions = useExpressionsInSet(id!) || [];
  return (
    <Link
      href={{
        pathname: "/expression-sets/details",
        query: { "set-id": id },
      }}
      passHref
    >
      <a>
        <ExpressionSetCard
          name={name}
          description={description}
          expression_count={expressions.length}
        />
      </a>
    </Link>
  );
}

export default dynamic(() => Promise.resolve(ExpressionSetListPage), {
  ssr: false,
});
